<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Mycoursestatus block
 *
 * @package    block_mycoursestatus
 * @copyright  2014 Lavanya Manne
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require_once('../../../config.php');
global $CFG, $DB, $PAGE, $COURSE, $USER;
require_once($CFG->dirroot.'/blocks/mycoursestatus/classes/module.php');
$PAGE->requires->css('/blocks/mycoursestatus/styles.css');

$courseid = required_param('id', PARAM_INT);
$PAGE->set_url(new moodle_url('/blocks/mycoursestatus/report.php', array('id' => $courseid)));

/* Basic access checks */
if (!$course = $DB->get_record('course', array('id' => $courseid))) {
    print_error('nocourseid');
}
require_login($courseid);

$context = context_course::instance($courseid);
require_capability('gradereport/user:view', $context);

if (isguestuser()) {
    /* Force them to see system default, no editing allowed */
    $userid = null;
    $USER->editing = $edit = 0;
    $context = context_system::instance(); // A:get_context_instance(CONTEXT_SYSTEM) turns into context_system::instance().
    $PAGE->set_blocks_editing_capability('moodle/my:configsyspages');
    $header = $course->fullname;
} else {
    /* We are trying to view or edit our own My Moodle page i.e., admin part.*/
    $userid = $USER->id;
    $context = get_context_instance(CONTEXT_USER, $USER->id);
    $PAGE->set_blocks_editing_capability('moodle/my:manageblocks');
    $header = $course->fullname;
}

$PAGE->set_context(get_system_context(CONTEXT_COURSE));
$PAGE->set_title($header);
$PAGE->set_heading($header);

/* Breadcrumbs or navbar */
$coursenode = $PAGE->navigation->find($courseid, navigation_node::TYPE_COURSE);
$thingnode = $coursenode->add(get_string('report', 'block_mycoursestatus'));
$thingnode->make_active();

echo $OUTPUT->header();

echo html_writer::start_tag('div', array('class' => 'contentgraph'));
$modreport = new module($CFG, $DB);
echo html_writer::div(get_string('creport', 'block_mycoursestatus'), 'rheader');
echo html_writer::div('<b>Course: '.$course->fullname.'</b>', 'report');
echo html_writer::div(get_string('piechart', 'block_mycoursestatus'));

echo html_writer::start_tag('div', array('class' => 'wpiechart'));
$modinfo = get_fast_modinfo($courseid);
foreach ($cms = $modinfo->get_cms() as $cminfo) {
    $moduleid   = $cminfo->id;
    $modulename = $cminfo->get_formatted_name();
    $sql = "SELECT DISTINCT c.id AS cid,
            c.fullname,
            cm.id AS moduleid,
            (SELECT count(cmc.userid) FROM {course_modules_completion} cmc WHERE cmc.coursemoduleid = cm.id
             AND cmc.completionstate BETWEEN 1 AND 3) AS 'users'
            FROM
            {course} c
            JOIN {course_modules} cm ON cm.course = c.id
            JOIN {modules} m ON m.id = cm.module
            WHERE
            cm.deletioninprogress=0
            AND m.id NOT IN(13)
            AND cm.id = ".$moduleid."
            AND c.id = ".$courseid." ";
    $mods = $DB->get_records_sql($sql);
    foreach ($mods as $m) {
        // Display piechart.
        $series = new \core\chart_series(''.$modulename.'', [$modulename, $m->users]);
        $labels = ['Module', 'Completed users'];
        $chart = new \core\chart_pie();
        $chart->set_title($m->fullname);
        $chart->add_series($series);
        $chart->set_labels($labels);
        echo $OUTPUT->render($chart);
    }
}

echo html_writer::start_tag('div', array('class' => 'wpiechart'));
echo html_writer::end_tag('div', array('class' => 'contentgraph'));
echo $OUTPUT->footer();
