<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Mycoursestatus block
 *
 * @package    block_mycoursestatus
 * @copyright  2014 Lavanya Manne
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require_once('../../../config.php');
global $CFG, $DB, $PAGE, $COURSE, $USER;
require_once($CFG->dirroot.'/blocks/mycoursestatus/classes/module.php');
$PAGE->requires->css('/blocks/mycoursestatus/styles.css');

$courseid = required_param('id', PARAM_INT);
$PAGE->set_url(new moodle_url('/blocks/mycoursestatus/report.php', array('id' => $courseid)));

/* Basic access checks */
if (!$course = $DB->get_record('course', array('id' => $courseid))) {
    print_error('nocourseid');
}
require_login($courseid);

// TCPDF library.
require_once($CFG->libdir.'/tcpdf/tcpdf.php');
require_once($CFG->libdir.'/pdflib.php');

// Create new PDF document.
ob_clean();
$pdf = new pdf();

// Set document information.
$pdf->SetCreator(PDF_CREATOR);
$pdf->SetTitle($usertitle1);
$pdf->setPageOrientation($orientation = 'L', $unit = 'mm', $format = 'A4', $unicode = true,
                         $encoding = 'UTF-8', $diskcache = false, $pdfa = false);

// Set default header data.
$pdfheaderlogo = "pix/logo.png";
$pdfheaderlogowidth = "200px";
$pdfheadertitle = "";
$pdfheaderstring = "Moodle 39\n" . "Telephone: 1-000-000-0000\n" . "Email: moodle@moodle.org";
$pdf->SetHeaderData($pdfheaderlogo, $pdfheaderlogowidth, $pdfheadertitle, $pdfheaderstring);

// Set header and footer fonts.
$pdf->setHeaderFont(Array(PDF_FONT_NAME_MAIN, '', PDF_FONT_SIZE_MAIN));
$pdf->setFooterFont(Array(PDF_FONT_NAME_DATA, '', PDF_FONT_SIZE_DATA));

// Set default monospaced font.
$pdf->SetDefaultMonospacedFont(PDF_FONT_MONOSPACED);

// Set margins.
$pdf->SetMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP, PDF_MARGIN_RIGHT);
$pdf->SetHeaderMargin(PDF_MARGIN_HEADER);
$pdf->SetFooterMargin(PDF_MARGIN_FOOTER);

// Set auto page breaks.
$pdf->SetAutoPageBreak(true, 15);

// Set image scale factor.
$pdf->setImageScale(0.47);

// Set font.
$pdf->SetFont('helvetica', '', 10);

// Add a page.
$pdf->AddPage();

$usertitle = get_string('creport', 'block_mycoursestatus');
$output .= '<div style="text-align:center;font-weight:bold;font-size:7px;text-decoration:underline;color:#084b8a;">
'.$usertitle.'</div>';
$output .= html_writer::div('<b>Fullname : '.$USER->firstname.'&nbsp;'.$USER->lastname.'</b>', 'report');
$output .= html_writer::div('<b>Course : '.$course->fullname.'</b>', 'report');

$modreport = new module($CFG, $DB);
if ($modreport->module_conds()) {
    $output .= html_writer::div('The course <b>'.$course->fullname.'</b> has set to <b>' .
                                get_string('cconda', 'block_mycoursestatus').'</b> and the modules required for
                                completion are:', 'cond1');
    $output .= html_writer::div($modreport->module_conds(), 'cond2');
}

if ($modreport->modcourse_mod()) {
    $output .= html_writer::div('The course <b>'.$course->fullname.'</b> has set to <b>' .
                                get_string('ccondb', 'block_mycoursestatus').'</b> and the modules required for
                                completion are:', 'cond1');
    $output .= html_writer::div($modreport->modcourse_mod(), 'cond2');
}

if ($modreport->course_grade()) {
    $output .= html_writer::div('The course <b>'.$course->fullname.'</b> has set to <b>' .
                                get_string('ccondc', 'block_mycoursestatus').'</b> and the required course grade for
                                completion is <b>'.$modreport->course_grade().'</b>', 'cond1');
}
$output .= html_writer::div('', 'cond1');

// Display resource modules.
$notgradetable = new html_table();
$notgradetable->head = array('Resource Modules', 'Status');
$notgradetable->attributes['style'] = "padding:2px;width:100%;cellspacing:2;cellpadding:0;text-align:center;";
$notgradetable->attributes['border'] = "0.1";
$modinfo = get_fast_modinfo($courseid);
foreach ($cms = $modinfo->get_cms() as $cminfo) {
    $notgraded = $DB->get_recordset_sql('SELECT cmc.coursemoduleid
                                          FROM {course_modules_completion} cmc
                                          JOIN {course_modules} cm ON cm.id = cmc.coursemoduleid
                                          JOIN {modules} m ON m.id= cm.module
                                          WHERE cm.deletioninprogress=0
                                          AND m.id IN (3,8,12,13,16,18,21)
                                          AND cmc.viewed = 1
                                          AND cmc.coursemoduleid = '.$cminfo->id.'
                                          AND cmc.userid= '.$USER->id.'
                                          AND cm.course = '.$courseid.' ORDER BY cm.id');
    foreach ($notgraded as $ngd) {
        $notgradetable->data[] = new html_table_row(array(implode(array($cminfo->get_formatted_name())),
                                 '<center>Viewed</center>'));
    }
}

// Display activity modules.
$gradetable = new html_table();
$gradetable->head = array('Activity Modules', 'Grade');
$gradetable->attributes['style'] = "padding:2px;width:100%;cellspacing:2;cellpadding:0;text-align:center;";
$gradetable->attributes['border'] = "0.1";
$graded = $DB->get_recordset_sql('SELECT gi.itemname,
                                         gg.finalgrade
                                  FROM {grade_items} gi JOIN {grade_grades} gg ON gi.id = gg.itemid
                                  WHERE gi.itemtype IN ("mod")
                                  AND gg.finalgrade IS NOT NULL
                                  AND gi.courseid = '.$courseid.'
                                  AND gg.userid = '.$USER->id.' ORDER BY gi.itemname');
foreach ($graded as $gd) {
    $gradetable->data[] = new html_table_row(array(implode(array($gd->itemname)), '<center>'.$gd->finalgrade.'</center>'));
}

$output .= html_writer::table($notgradetable);
$output .= '<br><br><br>';
$output .= html_writer::table($gradetable);

$pdf->WriteHTML($output);
$pdf->Output('reportpdf.pdf');
ob_end_clean();
echo html_writer::table($notgradetable);
